@@ -1,11 +1,4 @@
-// $Revision: 1.13 $$Date: 2005-01-24 10:18:02 -0500 (Mon, 24 Jan 2005) $$Author: wsnyder $  -*- C++ -*-
-//*************************************************************************
-// DESCRIPTION: Verilog::Preproc: Error handling implementation
-//
-// Code available from: http://www.veripool.com/verilog-perl
-//
-// Authors: Wilson Snyder
-//
+// $Revision: 1.13 $$Date: 2005-02-21 10:11:49 -0500 (Mon, 21 Feb 2005) $$Author: wsnyder $  -*- C++ -*-
 //*************************************************************************
 //
 // Copyright 2000-2005 by Wilson Snyder.  This program is free software;
@@ -18,12 +11,20 @@
 // GNU General Public License for more details.
 //
 //*************************************************************************
+/// \file
+/// \brief Verilog::Preproc: Error handling implementation
+///
+/// Authors: Wilson Snyder
+///
+/// Code available from: http://www.veripool.com/verilog-perl
+///
+//*************************************************************************
 
 #include <stdio.h>
 
 #include "VFileLine.h"
 
-int VFileLine::s_numErrors = 0;
+int VFileLine::s_numErrors = 0;		///< Number of errors detected
 
 //============================================================================
 
